@@ -7,6 +7,7 @@ import sys
 
 from .commands import merge_pr
 from .commands import deploy
+from .commands import rollback
 from .commands import create_branch
 from .commands import open_pr
 from .commands import lock_project
@@ -52,6 +53,9 @@ parser_merge_pr = subparsers.add_parser(
 parser_deploy = subparsers.add_parser(
     "deploy", help="Deploy in produzione del branch master")
 
+parser_rollback = subparsers.add_parser(
+    "rollback", help="Rollback in produzione")
+
 
 def dispatch(cmd_args):
     args = parser.parse_args(args=cmd_args)
@@ -65,6 +69,8 @@ def dispatch(cmd_args):
         return create_branch.entrypoint(args)
     elif(args.command == "deploy"):
         return deploy.entrypoint(args)
+    elif(args.command == "rollback"):
+        return rollback.entrypoint(args)
     elif(args.command == "merge-pr"):
         return merge_pr.entrypoint(args)
     elif(args.command == "open-pr"):
