@@ -74,7 +74,8 @@ def entrypoint(args):
                     "Non sono riuscito ad aggiungere i tag di review: {}".format(e))
                 sys.exit(-1)
     else:
-        logger.warning('Reviewers inseriti SOLO su GitHub. Nessuna card collegata o card nel nome del branch inesistente su YouTrack.')
+        logger.warning(
+            'Reviewers inseriti SOLO su GitHub. Nessuna card collegata o card nel nome del branch inesistente su YouTrack.')
 
 
 def ask_reviewer():
@@ -84,7 +85,7 @@ def ask_reviewer():
     youtrack_reviewers = []
 
     youtrack_reviewers = list(
-        input("Scegli i reviewers (separati da spazio) > ").split())
+        input("Scegli i reviewers (nome.cognome - separati da spazio - premere TAB per autocomplete) > ").split())
 
     if len(youtrack_reviewers) < 1:
         logger.warning("Devi inserire almeno un reviewer")
