@@ -3,8 +3,11 @@ from ..lib.handler.youtrack_handler import YoutrackHandler
 from ..lib.handler.github_handler import GithubHandler
 from ..lib.handler.slack_handler import SlackHandler
 from ..lib.handler import prompt_utils
+from ..lib.handler import git_handler as git
+from ..lib.handler import drone_handler as drone
 from ..lib.logger import Logger
 from ..lib.config import Config
+from halo import Halo
 import sys
 import semver
 
@@ -21,32 +24,39 @@ def entrypoint(args):
             "Impossibile continuare con il deploy a causa di migration presenti. Chiedi ai devops di effettuare il deploy.")
         sys.exit(-1)
 
+    git.is_dirty(args.project)
+    git.fetch(args.project)
     repo = github.get_repo(args.project)
 
     latest_release = get_release(repo)
 
     versions = bump_versions(latest_release.title)
 
-    new_version = prompt_utils.ask_choices(
-        "Seleziona versione:",
-        [
-            {"name": "Patch {}".format(versions["patch"]), "value": versions["patch"]},
-            {"name": "Minor {}".format(versions["minor"]), "value": versions["minor"]},
-            {"name": "Major {}".format(versions["major"]), "value": versions["major"]},
-        ]
-    )
-
     commits = github.get_commits_since_release(repo, latest_release)
-    message = "\n".join(["* " + c.commit.message.splitlines()[0] for c in commits])
+
+    check_migrations_deploy(commits)
+
+    message = "\n".join(["* " + c.commit.message.splitlines()[0]
+                         for c in commits])
 
     logger.info("\nLista dei commit:\n{}\n".format(message))
 
     if not prompt_utils.ask_confirm("Vuoi continuare?"):
         sys.exit(-1)
 
-    release_state = config["youtrack"]["release_state"]
+    new_version = prompt_utils.ask_choices(
+        "Seleziona versione:",
+        [
+            {"name": "Patch {}".format(
+                versions["patch"]), "value": versions["patch"]},
+            {"name": "Minor {}".format(
+                versions["minor"]), "value": versions["minor"]},
+            {"name": "Major {}".format(
+                versions["major"]), "value": versions["major"]},
+        ]
+    )
 
-    logger.info("Imposto le card in {}".format(release_state))
+    release_state = config["youtrack"]["release_state"]
 
     deployed_cards_link = []
     try:
@@ -55,30 +65,41 @@ def entrypoint(args):
             youtrack.update_state(
                 issue_id, release_state
             )
+        logger.info("Imposto le card in {}".format(release_state))
     except:
-        logger.warning("Si è verificato un errore durante lo spostamento delle card in {}".format(release_state))
+        logger.warning(
+            "Si è verificato un errore durante lo spostamento delle card in {}".format(release_state))
     finally:
-        create_release(repo, new_version, message, args.project, deployed_cards_link)
+        create_release(repo, new_version, message,
+                       args.project, deployed_cards_link)
 
 
 def get_release(repo):
-    latest_release = github.get_latest_release_if_exists(repo)
-    if latest_release:
+    with Halo(text='Loading...', spinner='dots', color='magenta'):
+        latest_release = github.get_latest_release_if_exists(repo)
+        tags = repo.get_tags()
+        tag = git.get_last_tag_number(tags)
+    if latest_release and latest_release.title == tag:
         logger.info("La release attuale è {}".format(latest_release.title))
         return latest_release
     else:
-        tag = repo.get_tags()[0]
-        logger.info("L'ultimo tag trovato è {}".format(tag.name))
-
-        return repo.create_git_release(tag.name, tag.name, "New release from tag {}".format(tag.name))
+        logger.info("L'ultimo tag trovato è {}".format(tag))
+        if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
+            sys.exit(-1)
+        return repo.create_git_release(tag, tag, "New release from tag {}".format(tag))
 
 
 def create_release(repo, new_version, message, project, deployed_cards_link):
     new_release = repo.create_git_release(new_version, new_version, message)
     if new_release:
-        logger.info("La release è stata creata! Link: {}".format(new_release.html_url))
+        logger.info("La release è stata creata! Link: {}".format(
+            new_release.html_url))
         slack.post(
             "#deploy", "ho effettuato il deploy di {}. Nuova release con versione {} {}\n{}".format(project, new_version, new_release.html_url, deployed_cards_to_string(deployed_cards_link)))
+        drone_url = drone.get_last_build_url(args.project)
+        if drone_url:
+            logger.info(
+                "Puoi seguire il deploy in produzione su {}".format(drone_url))
 
 
 def bump_versions(current):
@@ -94,3 +115,19 @@ def deployed_cards_to_string(cards):
         return ""
     else:
         return "\n".join(cards)
+
+
+def check_migrations_deploy(commits):
+    if len(commits) == 0:
+        logger.error("ERRORE: nessun commit trovato")
+        sys.exit(-1)
+    elif len(commits) == 1:
+        files_changed = git.files_changed_between_commits(
+            "--raw", "{}~".format(commits[0].sha))
+    else:
+        files_changed = git.files_changed_between_commits(
+            "{}~".format(commits[-1].sha), commits[0].sha)
+    if git.migrations_found(files_changed):
+        logger.warning("ATTENZIONE: migrations rilevate nel codice")
+        if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
+            sys.exit(-1)
