@@ -1,10 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from __future__ import print_function, unicode_literals
-from ..lib.handler import prompt_utils
 from ..lib.handler.captainhook_handler import CaptainHook
 from ..lib.logger import Logger
-import os
 import sys
 
 logger = Logger()
@@ -12,20 +10,16 @@ lock = CaptainHook()
 
 
 def entrypoint(args):
-    project = os.path.basename(os.getcwd())
-    if not prompt_utils.ask_confirm("Vuoi continuare sul progetto {}?".format(project)):
-        sys.exit(-1)
-
     if(args.action in ['lock', 'l']):
-        req = lock.lock_project(project)
+        req = lock.lock_project(args.project)
         handle_request(req)
         logger.info(
-            'Bloccato deploy su staging del progetto {}'.format(project))
+            'Bloccato deploy su staging del progetto {}'.format(args.project))
     elif(args.action in ['unlock', 'u']):
-        req = lock.unlock_project(project)
+        req = lock.unlock_project(args.project)
         handle_request(req)
         logger.info(
-            'Abilitato deploy su staging del progetto {}'.format(project))
+            'Abilitato deploy su staging del progetto {}'.format(args.project))
     else:
         logger.warning('Non ho capito che cosa devo fare')
         sys.exit(-1)
