@@ -26,6 +26,8 @@ def entrypoint(args):
     branch_name = pr.head.ref
     youtrack_id = youtrack.get_card_from_name(branch_name)
 
+    check_migrations_merge(pr)
+
     logger.info("Eseguo il merge...")
 
     merge_status = pr.merge(
@@ -43,13 +45,9 @@ def entrypoint(args):
     else:
         logger.info("Pull request mergiata su master!")
 
-    logger.info("Cancello il branch da github...")
-
-    if git.delete_remote_branch(args.project, branch_name):
-        logger.info("Branch remoto eliminato.")
-    else:
-        logger.error("Si è verificato un errore durante la cancellazione del branch remoto.")
-        logger.error("Elimina il branch manualmente da {}".format(pr.html_url))
+    git.fetch(args.project)
+    if git.remote_branch_exists(args.project, branch_name):
+        git.delete_remote_branch(args.project, branch_name)
 
     if prompt_utils.ask_confirm("Vuoi bloccare staging? (Necessario se bisogna testare su staging)".format(args.project), default=False):
         lock.lock_project(args.project)
@@ -72,17 +70,21 @@ def entrypoint(args):
 def select_pr(project):
     if github.user_is_admin(project):
         logger.info("Ottengo le pull request da GitHub...")
-        logger.warning("Sei admin del repository, puoi fare il merge skippando i check (CI, review, ecc...)\nDa grandi poteri derivano grandi responsabilita'")
+        logger.warning(
+            "Sei admin del repository, puoi fare il merge skippando i check (CI, review, ecc...)\nDa grandi poteri derivano grandi responsabilita'")
         prs = github.get_list_pr(project)
     else:
         logger.info("Ottengo le pull request con check verdi da GitHub...")
-        prs = list(filter(lambda pr: pr.mergeable and pr.mergeable_state == "clean", github.get_list_pr(project)))
+        prs = list(filter(lambda pr: pr.mergeable and pr.mergeable_state ==
+                          "clean", github.get_list_pr(project)))
 
-    if prs:
-        choices = [{"name": "{} {}".format(i.number, i.title), "value": i} for i in prs]
+    if prs.totalCount > 0:
+        choices = [{"name": "{} {}".format(
+            i.number, i.title), "value": i} for i in prs]
         return prompt_utils.ask_choices('Seleziona PR: ', choices)
     else:
-        logger.warning("Non esistono pull request pronte per il merge, per favore controlla su https://github.com/primait/{}/pulls".format(project))
+        logger.warning(
+            "Non esistono pull request pronte per il merge, per favore controlla su https://github.com/primait/{}/pulls".format(project))
         sys.exit(-1)
 
 
@@ -93,7 +95,8 @@ def stop_if_master_locked(project):
         sys.exit(-1)
 
     if request.json()["locked"]:
-        logger.error("Il progetto è lockato su master. Impossibile continuare.")
+        logger.error(
+            "Il progetto è lockato su master. Impossibile continuare.")
         sys.exit(-1)
 
 
@@ -103,3 +106,11 @@ def get_drone_build(project, sha):
     if drone_build != "":
         return drone_build
     return None
+
+
+def check_migrations_merge(pr):
+    files_changed = [x.filename for x in pr.get_files()]
+    if git.migrations_found(files_changed):
+        logger.warning("ATTENZIONE: migrations rilevate nel codice")
+        if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
+            sys.exit(-1)
