@@ -15,10 +15,10 @@ logger = Logger()
 
 def entrypoint(args):
     branch_name = git.current_branch_name()
-    git.is_dirty(args.project)
-
+    
     if not git.remote_branch_exists(args.project, branch_name):
-        logger.error("Non ho trovato il branch {} su GitHub, per favore esegui un 'git push' manualmente".format(branch_name))
+        logger.error(
+            "Non ho trovato il branch {} su GitHub, per favore esegui un 'git push' manualmente".format(branch_name))
         sys.exit(-1)
 
     youtrack_id = youtrack.get_card_from_name(branch_name)
@@ -26,7 +26,8 @@ def entrypoint(args):
         pulls = github.get_pr_from_branch(args.project, branch_name)
         if pulls.totalCount:
             pr = pulls[0]
-            logger.info("Esiste una pull request su GitHub per il branch {}".format(branch_name))
+            logger.info(
+                "Esiste una pull request su GitHub per il branch {}".format(branch_name))
 
             if prompt_utils.ask_confirm("Vuoi modificare la description della pull request?"):
                 edit_pr(pr)
@@ -35,7 +36,8 @@ def entrypoint(args):
         else:
             create_pr(args.project, branch_name, youtrack_id)
     else:
-        logger.warning("Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste")
+        logger.warning(
+            "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste")
         if not prompt_utils.ask_confirm("Vuoi collegare la pull request con una issue?"):
             create_pr(args.project, branch_name)
         else:
@@ -50,7 +52,8 @@ def edit_pr(pr):
 
 def create_pr(repo, branch_name, id_card=None):
     if id_card:
-        logger.info("Creo una pull request sul progetto {} per il branch {} collegato con la card {}".format(repo, branch_name, id_card))
+        logger.info("Creo una pull request sul progetto {} per il branch {} collegato con la card {}".format(
+            repo, branch_name, id_card))
         link = youtrack.get_link(id_card)
         title = "[{}]: {}".format(
             id_card, youtrack.get_issue(id_card)["summary"])
@@ -74,7 +77,8 @@ def create_pr(repo, branch_name, id_card=None):
 
     if id_card:
         update_card(id_card, repo, pr.html_url)
-        logger.info("Inserito link della pull request nella card {}".format(id_card))
+        logger.info(
+            "Inserito link della pull request nella card {}".format(id_card))
 
 
 def ask_for_description(pr_body=""):
@@ -83,14 +87,16 @@ def ask_for_description(pr_body=""):
         'Inserisci la description della PR: ', pr_body)
 
     if description == "":
-        logger.warning("La descrizione della pull request non può essere vuota")
+        logger.warning(
+            "La descrizione della pull request non può essere vuota")
         ask_for_description(pr_body)
     else:
         return description
 
 
 def ask_for_id_card():
-    id_card = prompt_utils.ask_questions_input('Inserisci ID della card (ex: PRIMA-1234): ')
+    id_card = prompt_utils.ask_questions_input(
+        'Inserisci ID della card (ex: PRIMA-1234): ')
     if youtrack.validate_issue(id_card):
         return id_card
     else:
@@ -103,4 +109,10 @@ def update_card(id_card, repo, link):
 
 
 def ask_for_title():
-    return prompt_utils.ask_questions_input('Inserisci il titolo della pull request: ')
+    title = prompt_utils.ask_questions_input(
+        'Inserisci il titolo della pull request: ')
+    if title == "":
+        logger.warning("Il titolo della pull request non può essere vuoto")
+        ask_for_title()
+    else:
+        return title
