@@ -6,6 +6,8 @@ import os
 import subprocess
 import sys
 import re
+import semver
+from halo import Halo
 
 logger = Logger()
 config = Config().load()
@@ -24,10 +26,10 @@ def checkout(repo, branch, new=False):
     try:
         if new:
             subprocess.run(['git', 'checkout', '-b', branch],
-                           cwd=_get_path(repo), check=True)
+                           cwd=_get_path(repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
         else:
             subprocess.run(['git', 'checkout', branch],
-                           cwd=_get_path(repo), check=True)
+                           cwd=_get_path(repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
             pull(repo, rebase=True)
     except (CalledProcessError) as e:
         if (e.returncode == 128):
@@ -63,24 +65,29 @@ def push(repo, branch, remote='origin'):
 
 
 def pull(repo, rebase=False):
-    try:
-        if rebase:
-            subprocess.run(['git', 'pull', "--rebase"],
-                           cwd=_get_path(repo), check=True)
-        else:
-            subprocess.run(['git', 'pull'], cwd=_get_path(repo), check=True)
-    except (CalledProcessError) as e:
-        logger.error("Errore eseguendo il comando: {}".format(e))
-        sys.exit(-1)
+    with Halo(text='Pulling...', spinner='dots', color='magenta'):
+        try:
+            if rebase:
+                subprocess.run(['git', 'pull', "--rebase"],
+                               cwd=_get_path(repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+            else:
+                subprocess.run(['git', 'pull'],
+                               cwd=_get_path(repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        except (CalledProcessError) as e:
+            logger.error("Errore eseguendo il comando: {}".format(e))
+            sys.exit(-1)
 
 
 def fetch(repo, remote='origin'):
-    try:
-        subprocess.run(['git', 'fetch'], cwd=_get_path(repo), check=True)
-        subprocess.run(['git', 'fetch', '-p', remote], cwd=_get_path(repo), check=True)
-    except (CalledProcessError) as e:
-        logger.error("Errore eseguendo il comando: {}".format(e))
-        sys.exit(-1)
+    with Halo(text='Fetching...', spinner='dots', color='magenta'):
+        try:
+            subprocess.run(['git', 'fetch', '--quiet'], cwd=_get_path(
+                repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+            subprocess.run(['git', 'fetch', '-p', remote, '--quiet'],
+                           cwd=_get_path(repo), check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        except (CalledProcessError) as e:
+            logger.error("Errore eseguendo il comando: {}".format(e))
+            sys.exit(-1)
 
 
 def sync(repo):
@@ -116,18 +123,19 @@ def get_git_username():
 
 def get_last_tag(project):
     sync(project)
-    return subprocess.check_output(["git", "describe", "--abbrev=0", "--tags"]).decode('ascii').strip()
+    return subprocess.check_output(["git", "describe", "--abbrev=0", "--tags"]).decode('utf-8').strip()
 
 
 def search_remote_branch(repo, regex):
     try:
         output = subprocess.run(['git', 'branch', '-r', '--list', regex],
-                       cwd=_get_path(repo), check=True, stdout=subprocess.PIPE)
+                                cwd=_get_path(repo), check=True, stdout=subprocess.PIPE)
 
         return output.stdout.decode("utf-8").strip('\n').strip().strip('origin/')
     except (CalledProcessError):
         return ""
 
+
 def remote_branch_exists(repo, branch):
     try:
         subprocess.run(['git', 'show-ref', '--quiet', 'refs/remotes/origin/{}'.format(branch)],
@@ -166,3 +174,34 @@ def is_dirty(repo):
         logger.error(
             "Hai modifiche non committate su {} oppure non è un repository!".format(repo))
         sys.exit(-1)
+
+
+def files_changed_between_commits(from_commit, to_commit):
+    p = subprocess.Popen(
+        ["git", "diff", from_commit, to_commit, "--name-only"], stdout=subprocess.PIPE)
+    result = p.communicate()[0]
+    return result.decode('utf-8').splitlines()
+
+
+def migrations_found(files_changed):
+    for file in files_changed:
+        if 'migration' in file.lower():
+            return True
+    return False
+
+
+def get_last_tag_number(tags):
+    for tag in tags:
+        if is_semver(tag.name):
+            return tag.name
+        else:
+            continue
+    logger.warning("Nessun tag trovato, sto per pubblicare tag 0.1.0")
+    return "0.1.0"
+
+
+def is_semver(tag):
+    try:
+        return semver.parse(tag)
+    except:
+        return None
