@@ -70,3 +70,9 @@ class GithubHandler(metaclass=Singleton):
 
     def user_is_admin(self, repo):
         return self.get_repo(repo).permissions.admin
+
+    def get_release_if_exists(self, repo, release):
+        try:
+            return repo.get_release(release)
+        except:
+            return None
