@@ -26,12 +26,6 @@ class YoutrackHandler(metaclass=Singleton):
     def get_issue(self, issue_id):
         return self._client.get_issue(issue_id)
 
-    def get_issues(self, slug, filter, min, max):
-        return self._client.get_issues(slug, filter, min, max)
-
-    def get_boards(self):
-        return self._client.get_all_agiles()
-
     def validate_issue(self, issue_id):
         try:
             if self.get_issue(issue_id):
@@ -51,19 +45,6 @@ class YoutrackHandler(metaclass=Singleton):
     def assign_to(self, issue_id, user):
         self._client.execute_command(issue_id, "Assignee {}".format(user))
 
-    def select_issue(self):
-        issue = prompt([
-            {
-                'type': 'input',
-                'name': 'name',
-                'message': "Inserisci il numero della issue su youtrack",
-                'default': "PRIMA-000",
-                'validate': lambda val: self.validate_issue(val)
-            }
-        ])
-
-        return self.get_issue(issue['name'])
-
     def get_link(self, issue_id):
         return "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/{}".format(issue_id)
 
@@ -85,3 +66,5 @@ class YoutrackHandler(metaclass=Singleton):
             if not self.validate_issue(id_card):
                 return None
             return id_card
+        else:
+            return None
